# -*- coding: utf-8 -*-
# Generated by Django 1.11.2 on 2018-09-12 13:26
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('adyengo', '0020_auto_20170616_1329'),
    ]

    operations = [
        migrations.AlterField(
            model_name='notification',
            name='payment_amount',
            field=models.PositiveIntegerField(),
        ),
        migrations.AlterField(
            model_name='session',
            name='payment_amount',
            field=models.PositiveIntegerField(),
        ),
    ]
