# -*- coding: utf-8 -*-
# Generated by Django 1.9 on 2016-10-13 16:48
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('adyengo', '0017_auto_20161013_1848'),
    ]

    operations = [
        migrations.AlterField(
            model_name='notification',
            name='payment_method',
            field=models.CharField(blank=True, choices=[('mc', 'Master Card'), ('dotpay', 'Dotpay'), ('bankTransfer_DE', 'German Banktransfer'), ('giropay', 'GiroPay'), ('diners', 'Diners Club'), ('visa', 'Visa'), ('bcmc', 'Bancontact card'), ('bankTransfer_IBAN', 'International Bank Transfer (IBAN)'), ('directdebit_NL', 'Direct Debit (Netherlands)'), ('discover', 'Discover'), ('bankTransfer', 'All banktransfers'), ('maestro', 'Maestro'), ('sepadirectdebit', 'SEPA Direct Debit'), ('amex', 'Amex'), ('directEbanking', 'SofortUberweisung'), ('bankTransfer_NL', 'Dutch Banktransfer'), ('ebanking_FI', 'Finnish E-Banking'), ('ideal', 'iDEAL'), ('card', 'All debit and credit cards'), ('elv', 'ELV'), ('paypal', 'PayPal')], max_length=50, null=True),
        ),
        migrations.AlterField(
            model_name='session',
            name='country_code',
            field=models.CharField(choices=[('NL', 'Netherlands'), ('GB', 'United Kingdom'), ('DE', 'Germany'), ('BE', 'Belgium')], max_length=2),
        ),
        migrations.AlterField(
            model_name='session',
            name='page_type',
            field=models.CharField(choices=[('skip', 'Skip'), ('single', 'Single'), ('multiple', 'Multiple')], default='skip', max_length=15),
        ),
        migrations.AlterField(
            model_name='session',
            name='recurring_contract',
            field=models.CharField(blank=True, choices=[('RECURRING,ONECLICK', 'Recurring and One click (user chooses)'), ('ONECLICK', 'One click'), ('RECURRING', 'Recurring')], max_length=50),
        ),
        migrations.AlterField(
            model_name='session',
            name='session_type',
            field=models.CharField(choices=[('api_recurring', 'API Recurring'), ('hpp_recurring', 'HPP Recurring'), ('hpp_regular', 'HPP Regular')], max_length=25),
        ),
        migrations.AlterField(
            model_name='session',
            name='shopper_locale',
            field=models.CharField(blank=True, choices=[('de_DE', 'German (Germany)'), ('fr_BE', 'French (Belgium)'), ('nl_NL', 'Dutch (Holland)'), ('nl_BE', 'Dutch (Belgium)'), ('en_GB', 'English (United Kingdom)')], default='nl_NL', max_length=5),
        ),
        migrations.AlterField(
            model_name='sessionallowedpaymentmethods',
            name='method',
            field=models.CharField(choices=[('mc', 'Master Card'), ('dotpay', 'Dotpay'), ('bankTransfer_DE', 'German Banktransfer'), ('giropay', 'GiroPay'), ('diners', 'Diners Club'), ('visa', 'Visa'), ('bcmc', 'Bancontact card'), ('bankTransfer_IBAN', 'International Bank Transfer (IBAN)'), ('directdebit_NL', 'Direct Debit (Netherlands)'), ('discover', 'Discover'), ('bankTransfer', 'All banktransfers'), ('maestro', 'Maestro'), ('sepadirectdebit', 'SEPA Direct Debit'), ('amex', 'Amex'), ('directEbanking', 'SofortUberweisung'), ('bankTransfer_NL', 'Dutch Banktransfer'), ('ebanking_FI', 'Finnish E-Banking'), ('ideal', 'iDEAL'), ('card', 'All debit and credit cards'), ('elv', 'ELV'), ('paypal', 'PayPal')], max_length=50),
        ),
        migrations.AlterField(
            model_name='sessionblockedpaymentmethods',
            name='method',
            field=models.CharField(choices=[('mc', 'Master Card'), ('dotpay', 'Dotpay'), ('bankTransfer_DE', 'German Banktransfer'), ('giropay', 'GiroPay'), ('diners', 'Diners Club'), ('visa', 'Visa'), ('bcmc', 'Bancontact card'), ('bankTransfer_IBAN', 'International Bank Transfer (IBAN)'), ('directdebit_NL', 'Direct Debit (Netherlands)'), ('discover', 'Discover'), ('bankTransfer', 'All banktransfers'), ('maestro', 'Maestro'), ('sepadirectdebit', 'SEPA Direct Debit'), ('amex', 'Amex'), ('directEbanking', 'SofortUberweisung'), ('bankTransfer_NL', 'Dutch Banktransfer'), ('ebanking_FI', 'Finnish E-Banking'), ('ideal', 'iDEAL'), ('card', 'All debit and credit cards'), ('elv', 'ELV'), ('paypal', 'PayPal')], max_length=50),
        ),
    ]
